@@ -1,6 +1,4 @@
 
-# $Id: MakefilePL.pm,v 1.6 2008/06/12 13:29:59 Martin Exp $
-
 =head1 NAME
 
 Devel::Fail::MakefilePL - a distro that always fails the `perl Makefile.PL` stage
@@ -20,7 +18,7 @@ This software is released under the same license as Perl itself.
 
 =head1 AUTHOR
 
-Martin Thurn, C<mthurn@cpan.org>, L<http://www.sandcrawler.com/SWB/cpan-modules.html>
+Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.
 
 =cut
 
@@ -28,7 +26,7 @@ package Devel::Fail::MakefilePL;
 use strict;
 use warnings;
 my
-$VERSION = do { my @r = (q$Revision: 1.6 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = 1.014;
 
 1;
 
